# Permissions used

* `tabs`: querying
* `history`: using local browser history
* `storage`: settings
* `webNavigation`: watching page state changes (e.g. when it's fully loaded)
* `contextMenus`: blacklisting/whitelisting urls
   * TODO think how it's gonna work on Android

* `notifications`: debugging mainly? TODO not sure if should get rid of them completely
